declare module "helpers" {
    export const TEST_FUNCTION: () => boolean;
    export const ERROR_MESSAGE: string;
    export const RESULT: {
        $invalid: boolean;
        $errors: any[];
        $messages: any[];
        $test: () => void;
        $reset: () => void;
    };
    export const hasOwn: (obj: {
        [key: string]: any;
    }, key: string) => boolean;
    export const isObject: (obj: {
        [key: string]: any;
    }) => boolean;
}
declare module "types" {
    import { ComputedRef } from 'vue';
    export type UnknownObject = {
        [key: string]: any;
    };
    export type Data = UnknownObject;
    export type Rule = {
        $test: (value: any) => boolean;
        $message?: string | ((value: any) => string);
        $key: string;
    };
    export type Rules = {
        [key: string]: Array<Rule> | Rules;
    };
    export type Dirt = {
        [key: string]: boolean | Dirt;
    };
    export type Error = {
        name: string;
    };
    export type Entry = {
        $invalid: boolean;
        $errors: Array<Error>;
        $messages: Array<string>;
        $test: () => void;
        $reset: () => void;
    };
    export type Entries = {
        [key: string]: Entry | Entries;
    };
    export type Args = [Data, Rules, Dirt, UnknownObject, Entries];
    export type ArgsObject = {
        data: Data;
        rules: Rules;
        dirt: Dirt;
        rawData: UnknownObject;
        entries: Entries;
    };
    export type Result = {
        $invalid: boolean;
        $errors: Array<Error>;
        $messages: Array<string>;
        $test: () => void;
        $reset: () => void;
        $dirty: boolean;
        [key: string]: any;
    };
    export type UseValidate = {
        result: ComputedRef<Result>;
        test: () => void;
        reset: () => void;
    };
}
declare module "vue-tiny-validate" {
    import { UnwrapRef, Ref } from 'vue';
    import { Data, Rules, UseValidate } from "types";
    const useValidate: (data: UnwrapRef<Data> | Ref<Data>, rules: UnwrapRef<Rules> | Ref<Rules>) => UseValidate;
    export default useValidate;
    export * from "types";
}
